#[non_exhaustive]pub enum ChainVerifyError {
BrokenLink {
entry_index: usize,
expected_hash: String,
stored_hash: String,
},
MissingChainHash {
entry_index: usize,
},
InvalidEntry {
entry_index: usize,
},
}Expand description
Error returned by verify_chain when the chain is broken.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BrokenLink
A computed hash does not match the stored chain_hash at this entry.
Fields
MissingChainHash
An entry could not be parsed (missing or invalid chain_hash field).
InvalidEntry
An audit entry is not a JSON object.
Every entry produced by the audit logger is a JSON object. If this variant is returned the supplied entries are malformed or have been tampered with.