pub struct AuthTokenResponseBuilder { /* private fields */ }Expand description
Builder for AuthTokenResponse.
Implementations
Sourceimpl AuthTokenResponseBuilder
impl AuthTokenResponseBuilder
Sourcepub fn access_token(self, access_token: impl Into<String>) -> Self
pub fn access_token(self, access_token: impl Into<String>) -> Self
Sets the access token.
Sourcepub fn refresh_token(self, refresh_token: impl Into<String>) -> Self
pub fn refresh_token(self, refresh_token: impl Into<String>) -> Self
Sets the refresh token.
Sourcepub fn token_type(self, token_type: impl Into<String>) -> Self
pub fn token_type(self, token_type: impl Into<String>) -> Self
Sets the token type (typically "Bearer").
Sourcepub const fn expires_in(self, expires_in: u64) -> Self
pub const fn expires_in(self, expires_in: u64) -> Self
Sets the number of seconds until the access token expires.
Sourcepub fn provider(self, provider: impl Into<String>) -> Self
pub fn provider(self, provider: impl Into<String>) -> Self
Sets the provider that authenticated the user.
Sourcepub fn build(self) -> Result<AuthTokenResponse, String>
pub fn build(self) -> Result<AuthTokenResponse, String>
Builds the AuthTokenResponse.
Errors
Returns an error string if any required field (access_token, token_type,
expires_in, or provider) was not set.